'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var Highlight = require('prism-react-renderer');
var defaultTheme = require('prism-react-renderer/themes/vsDark');
var PropTypes = require('prop-types');
var styled = require('styled-components');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var Highlight__default = /*#__PURE__*/_interopDefaultLegacy(Highlight);
var defaultTheme__default = /*#__PURE__*/_interopDefaultLegacy(defaultTheme);
var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);
var styled__default = /*#__PURE__*/_interopDefaultLegacy(styled);

/**
 * Generated Prism Theme from VSCode .json Themes
 *
 * @see https://github.com/FormidableLabs/prism-react-renderer/blob/95025358684be04865669bb912e8cf6203c1a391/tools/themeFromVsCode/README.md
 */
const vscDarkPlusTheme = {
    plain: {
        color: '#d4d4d4',
        backgroundColor: '#1e1e1e'
    },
    styles: [
        {
            types: ['prolog'],
            style: { color: 'rgb(0, 0, 128)' }
        },
        {
            types: ['comment', 'punctuation'],
            style: { color: 'rgb(106, 153, 85)' }
        },
        {
            types: ['builtin'],
            style: { color: 'rgb(79, 193, 255)' }
        },
        {
            types: ['number', 'variable', 'inserted'],
            style: { color: 'rgb(181, 206, 168)' }
        },
        {
            types: ['operator'],
            style: { color: 'rgb(212, 212, 212)' }
        },
        {
            types: ['constant'],
            style: { color: 'rgb(100, 102, 149)' }
        },
        {
            types: ['tag', 'changed', 'function', 'keyword'],
            style: { color: 'rgb(86, 156, 214)' }
        },
        {
            types: ['attr-name'],
            style: { color: 'rgb(156, 220, 254)' }
        },
        {
            types: ['deleted', 'string', 'attr-value'],
            style: { color: 'rgb(206, 145, 120)' }
        },
        {
            types: ['class-name'],
            style: { color: 'rgb(78, 201, 176)' }
        },
        {
            types: ['char'],
            style: { color: 'rgb(209, 105, 105)' }
        },
        {
            types: ['selector'],
            style: { color: 'rgb(215, 186, 125)' }
        },
        {
            // Fix tag color for HTML
            types: ['tag'],
            languages: ['markup'],
            style: { color: 'rgb(86, 156, 214)' }
        },
        {
            // Fix punctuation color for HTML
            types: ['punctuation'],
            languages: ['markup'],
            style: { color: '#808080' }
        },
    ]
};

/**
 * Code line
 */
const Line = styled__default['default'].div `
  text-indent: -${(props) => props.linenoWidth};
  padding-left: ${(props) => props.linenoWidth};
`;
/**
 * Code line number
 */
const LineNo = styled__default['default'].span `
  display: inline-block;
  width: ${(props) => props.linenoWidth};
  padding-right: 0.6em;
  color: ${(props) => props.linenoColor};
  cursor: default;
  user-select: none;
  text-align: right;
`;
/**
 * Content of CodeHighlighter
 *
 * @param props
 */
function HighlightContent(props) {
    const { tokens, linenoWidth, linenoColor, getLineProps, getTokenProps, onLineCountChange, } = props;
    React.useEffect(() => {
        if (onLineCountChange != null) {
            onLineCountChange(tokens.length);
        }
    }, [tokens.length, onLineCountChange]);
    return (React__default['default'].createElement(React__default['default'].Fragment, null, tokens.map((line, i) => (React__default['default'].createElement(Line, Object.assign({}, getLineProps({ line, key: i }), { linenoWidth: linenoWidth }),
        React__default['default'].createElement(LineNo, { key: "line-number", linenoWidth: linenoWidth, linenoColor: linenoColor }, i + 1),
        line.map((token, key) => (React__default['default'].createElement("span", Object.assign({}, getTokenProps({ token, key }))))))))));
}
/**
 *
 * @param props
 */
function CodeHighlighter(props) {
    const { lang, value: code, theme = defaultTheme__default['default'], linenoWidth = 0, linenoColor = '#858585', onLineCountChange, } = props;
    const result = React.useMemo(() => {
        return (React__default['default'].createElement(Highlight__default['default'], { Prism: Highlight.Prism, code: code, theme: theme, language: lang }, props => (React__default['default'].createElement(HighlightContent, Object.assign({}, props, { linenoWidth: linenoWidth, linenoColor: linenoColor, onLineCountChange: onLineCountChange })))));
    }, [code, theme, lang, linenoWidth, linenoColor, onLineCountChange]);
    return result;
}
CodeHighlighter.propTypes = {
    value: PropTypes__default['default'].string.isRequired,
    lang: PropTypes__default['default'].string,
    theme: PropTypes__default['default'].object,
    linenoWidth: PropTypes__default['default'].oneOfType([PropTypes__default['default'].number, PropTypes__default['default'].string]),
    onLineCountChange: PropTypes__default['default'].func,
};

exports.CodeHighlighter = CodeHighlighter;
exports.default = CodeHighlighter;
exports.vscDarkPlusTheme = vscDarkPlusTheme;
